@@ -1,3 +1,4 @@
+#define PCI_CONFIG_H
 #define PCI_ARCH_I386
 #define PCI_OS_LINUX
 #define PCI_HAVE_PM_LINUX_SYSFS
@@ -11,4 +12,6 @@
 #define PCI_COMPRESSED_IDS
 #define PCI_IDS "pci.ids.gz"
 #define PCI_PATH_IDS_DIR "/usr/share"
-#define PCILIB_VERSION "2.2.9"
+#define PCI_USE_DNS
+#define PCI_ID_DOMAIN "pci.id.ucw.cz"
+#define PCILIB_VERSION "3.1.2"
